<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>Stretch</name>
    <message>
        <location filename="../Stretch.js" line="+59"/>
        <source>First corner</source>
        <translation>Eerste hoekpunt</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second corner</source>
        <translation>Tweede hoekpunt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Reference point</source>
        <translation>Referentiepunt</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translation>Bestemmingspunt</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>No selected entities in given range</source>
        <translation>Geen geselecteerde objecten binnen het gegeven bereik</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No entities in given range</source>
        <translation>Geen objecten binnen het gegeven bereik</translation>
    </message>
    <message>
        <location filename="../StretchInit.js" line="+2"/>
        <source>&amp;Stretch</source>
        <translation>&amp;Uitrekken</translation>
    </message>
</context>
</TS>
